--- FL/Enumerations.H.original	2008-08-15 18:11:21.000000000 -0300
+++ FL/Enumerations.H	2008-09-12 10:33:26.000000000 -0300
@@ -287,7 +287,17 @@
    *  If the widget returns 1, it will receive the data in the immediatly 
    *  following FL_PASTE event.
    */
-  FL_DND_RELEASE	= 23
+  FL_DND_RELEASE	= 23,
+
+
+  /** The widget under the cursor has a chance to display a tooltip. 
+   *  When a widget receives this event, it can modify its tooltip. The
+   *  modified tooltip will be drawn. If the widget removes its tooltip,
+   *  the parent with a tooltip will be drawn.
+   *
+   *  \sa Fl_Widget::tooltip(const char *t)
+   */
+  FL_TOOLTIP        = 24
 };
 
 enum Fl_When { // Fl_Widget::when():
--- src/Fl_Tooltip.cxx.original	2008-08-15 18:11:21.000000000 -0300
+++ src/Fl_Tooltip.cxx	2008-09-12 10:28:21.000000000 -0300
@@ -153,6 +153,11 @@
   for (;;) {
     if (!tw) {exit_(0); return;}
     if (tw == widget_) return;
+
+    // Send the FL_TOOLTIP event to tw. The return value technically does not matter.
+	// The action to take will depend on the state of its tooltip.
+	tw->handle(FL_TOOLTIP);
+
     if (tw->tooltip()) break;
     tw = tw->parent();
   }
--- src/Fl_Group.cxx.original	2008-04-23 12:07:13.000000000 -0300
+++ src/Fl_Group.cxx	2008-09-12 11:57:10.000000000 -0300
@@ -251,6 +251,10 @@
     }
     return 1;
 
+  case FL_TOOLTIP:
+    if (tooltip()) return 1;
+    return 0;
+
   default:
     // For all other events, try to give to each child, starting at focus:
     for (i = 0; i < children(); i ++)
